@@ -20,12 +20,14 @@ public:
     QRegExp urlPattern() const;
     bool urlSupported(const QUrl &url) const;
     void checkUrl(const QUrl &url);
-    void getDownloadUrl(const QUrl &url);
+    void getDownloadRequest(const QUrl &url);
     inline bool loginSupported() const { return true; }
     void login(const QString &username, const QString &password);
     inline bool recaptchaRequired() const { return true; }
     inline QString recaptchaKey() const { return m_captchaKey; }
     inline QString recaptchaServiceName() const { return QString("MegaShares"); }
+    inline int maximumConnections() const { return m_connections; }
+    bool cancelCurrentOperation();
 
 public slots:
     void submitCaptchaResponse(const QString &challenge, const QString &response);
@@ -41,6 +43,9 @@ private slots:
     void updateWaitTime();
     void onWaitFinished();
 
+signals:
+    void currentOperationCancelled();
+
 private:
     QString m_fileName;
     QUrl m_url;
@@ -49,6 +54,7 @@ private:
     QString m_passportKey;
     QTimer *m_waitTimer;
     int m_waitTime;
+    int m_connections;
 };
 
 #endif // MEGASHARES_H
